@@ -203,18 +203,37 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r = response.json()
 
 
-    def query(self, dataset_slug, fields:list, filters:list=[], sorted_by:list=[]):
+    def query(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id=""):
+
+        if(fields==[]):
+            print("SELECT FIELDS")
+            return
+
+        if sorted_by is None:
+            sorted_by = []
+
+        if filters is None:
+            filters = []
+
+        if(dataset_id=="" and dataset_slug!=""):
+            datasetId = self.get_dataset_by_slug(self._agentId, dataset_slug)["id"]
+        elif(dataset_id!=""):
+            datasetId=dataset_id
+        else:
+            print("SPECIFY A DATASET ID OR SLUG")
+            return
 
-        dataset_id = self.get_dataset_by_slug(self._agentId, dataset_slug)
         body = {
             "agentId": self._agentId,
-            "datasetId": dataset_id,
+            "datasetId": datasetId,
             "fields": fields,
             "sortedBy": sorted_by,
             "filters": filters
         }
 
-        url = self.smart_insight_url = "/composed_queries/sdk"
+        print(body)
+
+        url = self.smart_insight_url + "/composed_queries/sdk"
 
         s = requests.Session()
         s.keep_alive = False
