@@ -263,15 +263,10 @@ class Query:
 
 @dataclass
 class SmartQuery:
-    queries: Optional[List[Query]] = None
+    queries: List[Query]
     components: Optional[List[Union[ChartComponent, MapComponent, QueryComponent, Component]]] = None
     javascript: Optional[List[str]] = None
 
-    def __init__(self, queries=None, components=None, javascript=None):
-        self.queries = queries
-        self.components = components
-        self.javascript = javascript
-
     @staticmethod
     def _get_tokens():
         f = open(os.path.join(os.path.dirname(__file__), "askdata_config", "compression_tokens.json"))
